@@ -1,8 +1,13 @@
+{-# LANGUAGE CPP #-}
 {-# LANGUAGE OverloadedStrings #-}
 
 module Clash.Tests.Core.Subst (tests) where
 
+#if MIN_VERSION_ghc(9,0,0)
+import           GHC.Types.SrcLoc        (noSrcSpan)
+#else
 import           SrcLoc                  (noSrcSpan)
+#endif
 
 import           Test.Tasty
 import           Test.Tasty.HUnit
@@ -13,6 +18,7 @@ import           Clash.Core.Type         (ConstTy(..), Type(ConstTy))
 import           Clash.Core.Subst
 import           Clash.Core.VarEnv
 import           Clash.Core.Var          (IdScope(..), Var(..))
+import           Clash.Unique            (Unique)
 
 fakeName :: Name a
 fakeName =
@@ -23,7 +29,7 @@ fakeName =
     , nameLoc=noSrcSpan
     }
 
-unique :: Int
+unique :: Unique
 unique = 20
 
 termVar :: Var Term
